<CsoundSynthesizer>
<CsOptions>
-o dac
</CsOptions>
<CsInstruments>

/* CONSTANTS */
sr = 11025
ksmps = 64
nchnls = 1
0dbfs = 1

/* FUNCTION TABLES */
; synth waveform
giSynth  ftgen 0, 0, 1024, 10, 1, 0.8, 0.3, 0.4, 0.3, 0.2, 0.3, 0.1, 0.4, 0.1, 0.3, 0.2, 0.4, 0.5
; blending window
giBlend ftgen 0, 0, 1024, 21, 1


/* INSTRUMENTS */
/*--1----------------*/
instr 1

  iNote    =        p4
  iFreq    mtof     iNote
  aSine    poscil   0.3,    iFreq
  aEnv     =        linen:a(ampdb(p5), 0.05, p3, 0.05)
  aNoise   =        random:a(-0.1,0.8)
  aSaw     =        vco2:a(k(aEnv),60,0)

  aSend    =        ((aSine * aNoise + aSaw) * aEnv)


  //Waveshape
  aOut = powershape:a(aSend, 0.5)

  chnset   aOut,    "Send01"

  outall(aOut)

  //Replay
  iNote += 1

  //-------p1-------p2--p3--p4--p5
  if(iNote <= 120) then
	  if(iNote%3 != 0) then
	    prints("Playing note %d\n", iNote)
	    schedule(1, 0.05,  0.1, iNote, -5)
	  else
	    prints("%d Note skipped..\n", iNote)
	    schedule(1, 0.05,  0.1, iNote, -60)
	  endif
  endif

endin
/*-------------------*/

/*--2----------------*/
instr 2

  aEnv = linen:a(0.4,0.01,p3,0.3)
  aEnv2 =  linen:a(0.4,0.01,p3,0.5)

  aSig = vco2:a(1.0,mtof(p7),0) ;regular Sawtooth
  aSig2 = vco2:a(0.5,mtof(p7+5),8) ;integrated Sawtooth

  aSum = (aSig * aEnv) + (aSig2 * aEnv2)
  chnset(aSum,"Send01")

	outall(aSum)

endin
/*-------------------*/

/*--3----------------*/
instr 3

  aFreqEnv = transeg:a(1,0.05,-4,0, 0.1,-4,0)

  aAmpEnv = transeg:a(0,0.005,-4,1,    0.8,-8,0)
  iNote = mtof:i(38)
  aSig = poscil:a(0.8,iNote + (iNote*6.5*aFreqEnv))

  aOut = (aSig * aAmpEnv)

  outall(aOut)

endin

/*-------------------*/

/*--4----------------*/
instr 4

  aEnv = transeg:a(0,0.6,-2,1,p4,0,1,1.0,-2,0)
  aSig = poscil3:a(0.6,mtof:i(60))
  aSig2 = poscil3:a(0.1,mtof:i(67))


  aOut = (aSig + aSig2) * aEnv

  outall(aOut)

endin



/*-------------------*/

/*-5-----------------*/
instr 5
  aEnv = transeg:a(0,0.6,-2,1,p4,0,1,1.0,-2,0)
  aSig = vco2:a(0.1,mtof:i(60),10) ;Square, no PWM
  aSig2 = vco2:a(0.15,mtof:i(71),12) ;Triangle
  aSig3 = vco2:a(0.08,mtof:i(74),12) ;Triangle


  aOut = (aSig + aSig2 + aSig3) * aEnv

  chnset(aOut,"Send01")

  outall(aOut)
endin

/*-------------------*/

/*-6-----------------*/
instr 6
  aEnv = transeg:a(0,0.01,4,1,0.02,-8,0)

  aFreqEnv = transeg:a(1,0.04,-4,0)
  aFreq = ((mtof:i(60)*4)*aFreqEnv) + mtof:i(60)

  aSig = poscil:a(0.8,aFreq)

  aTransient = aSig*aEnv
  aComb = vcomb:a(aTransient,1,0.04,0.08)
  aOut = aComb

  chnset(aOut,"Send01")

  outall(aOut)
endin

/*-------------------*/

/*-7-----------------*/
instr 7
  aEnv = transeg:a(0,0.4,-4,1,0.6,-4,0)

  aFreqEnv = transeg:a(1,0.03,-4,0)
  aFreq = ((mtof:i(60)*4)*aFreqEnv) + mtof:i(60)

  aSig = poscil:a(0.8,aFreq)

  aOut = aSig * aEnv

  chnset(aOut,"Send01")

  outall(aOut)
endin

/*-------------------*/

/*-8-----------------*/
instr 8
  aEnv = transeg:a(0,0.01,-4,1,0.05,-4,0)

  aSig = fractalnoise:a(0.8,0)

  aOut = aSig * aEnv

  chnset(aOut,"Send01")

  outall(aOut)
endin

/*-------------------*/



/*--R----------------*/
instr Reverb

  aInput	chnget		"Send01"
  aL,aR		freeverb	aInput,	aInput,	p4,	0.1
  				outs	aL

endin

</CsInstruments>
<CsScore>
//p1      p2    p3-dur p4     p5    p6    p7
//------------------------------------------
;i 1       0    0.1     60     -5
;i "Reverb" 0    8      0.8

;i 2		   0    0.4      0.2    0.05  2     61
;i "Reverb" 0   6      1.4

;i 3       0      0.8

;i 4       0     3     1

;i 5       0      3     1
;i "Reverb" 0   10      0.8

;i 6       0      1     1
;i "Reverb" 0   10      0.8

;i 7       0      1     1
;i "Reverb" 0   10      0.8

i 8       0      1     1
i "Reverb" 0   10      0.8

/*-------------------*/

</CsScore>
</CsoundSynthesizer>
